@@ -19,7 +19,7 @@
 #include <librnd/scconfig/hooks_common.h>
 #include <librnd/scconfig/rnd_hook_detect.h>
 
-#define version "1.1.1"
+#define version "1.1.2"
 
 #define REQ_LIBRND_MAJOR 4
 #define REQ_LIBRND_MINOR 0
@@ -48,7 +48,6 @@ static void help1(void)
 {
 	rnd_help1("camv-rnd");
 	printf(" --dot_camv_rnd=path        .camv-rnd config path under $HOME/\n");
-	printf(" --fontdir=path             system font dir that hosts ttf files\n");
 }
 
 /* Runs when a custom command line argument is found
@@ -63,8 +62,7 @@ int hook_custom_arg(const char *key, const char *value)
 		return 1;
 	}
 	if (strcmp(key, "fontdir") == 0) {
-		need_value("use --fontdir=path");
-		put("/local/camv/fontdir", value);
+		fprintf(stderr, "WARNING: --fontdir is ignored -camv-rnd doesn't need it; it uses an embedded vector font\n");
 		return 1;
 	}
 
@@ -131,8 +129,6 @@ int hook_detect_host()
 	return rnd_hook_detect_host();
 }
 
-#include "find_fontdir.c"
-
 /* Runs when things should be detected for the target system */
 int hook_detect_target()
 {
@@ -150,9 +146,6 @@ int hook_detect_target()
 
 	require("sys/types/size/4_u_int", 0, 1);
 
-	require("libs/sul/librnd-hid/*", 0, 1);
-	require("libs/sul/freetype2/*", 0, 1);
-
 	/* byaccic - are we able to regenerate languages? */
 	if (istrue(get("/local/camv/want_byaccic"))) {
 		require("parsgen/byaccic/*", 0, 0);
@@ -167,9 +160,6 @@ int hook_detect_target()
 		put("/local/camv/want_parsgen_byaccic", sfalse);
 	}
 
-	if (find_fontdir() != 0)
-		return 1;
-
 	return 0;
 }
 
@@ -215,7 +205,6 @@ int hook_generate()
 		print_sum_cfg_val("/local/prefix",              "installation prefix (--prefix)");
 		print_sum_cfg_val("/local/confdir",             "configuration directory (--confdir)");
 		print_sum_cfg_val("/local/camv/dot_camv_rnd",   ".camv_rnd config dir under $HOME");
-		print_sum_cfg_val("/local/camv/fontdir",        "system font dir");
 
 #undef plugin_def
 #undef plugin_header
