@@ -111,8 +111,12 @@ void camv_main_uninit(void)
 	rnd_hidlib_uninit(); /* plugin unload */
 }
 
+void camv_font_init(void);
+
 static void camv_main_init(void)
 {
+	camv.lysel = -1;
+	camv_font_init();
 	camv_plug_io_act_init();
 }
 
@@ -183,6 +187,8 @@ TODO("action list");
 		exit(n);
 	}
 
+	/* load files listed on command line, as a group, to keep their order from top to bottom */
+	camv_group_load_begin(&camv);
 	for(n = 0; ga.hid_argc > 0; n++, ga.hid_argc--) {
 		if (camv_io_load(&camv, ga.hid_argv[n]) != 0) {
 			rnd_message(RND_MSG_ERROR, "Can not load file '%s' (specified on command line) for exporting or printing\n", command_line_file);
@@ -191,6 +197,7 @@ TODO("action list");
 				exit(1);
 		}
 	}
+	camv_group_load_end(&camv);
 
 	if (rnd_main_exported(&ga, &camv.hidlib, camv_is_empty(&camv), NULL)) {
 		camv_main_uninit();
