@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2023 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,9 +44,12 @@ char camv_measurement_layer_name[] = "measure";
 
 void camv_layer_init(camv_layer_t *layer)
 {
+	static rnd_xform_mx_t ident = RND_XFORM_MX_IDENT;
+
 	memset(layer, 0, sizeof(camv_layer_t));
 	camv_rtree_init(&layer->objs);
 	layer->vis = 1;
+	memcpy(layer->mx, ident, sizeof(ident));
 }
 
 camv_layer_t *camv_layer_new(void)
@@ -56,13 +59,48 @@ camv_layer_t *camv_layer_new(void)
 	return res;
 }
 
-void camv_layer_append_to_design(camv_design_t *camv, camv_layer_t *layer)
+void camv_group_load_begin(camv_design_t *camv)
 {
-	assert(layer->parent == NULL);
-	vtp0_append(&camv->layers, layer);
-	layer->parent = camv;
+	camv->grp_load = 1;
+	camv->grp_idx_last = -1;
 }
 
+void camv_group_load_end(camv_design_t *camv)
+{
+	camv->grp_load = 0;
+}
+
+
+long camv_layer_append_to_design(camv_design_t *camv, camv_layer_t *layer)
+{
+	long res = -1;
+
+	assert(layer->parent == NULL);
+	if (camv->grp_load) {
+		if (camv->grp_idx_last < 0) {
+			camv->grp_idx_last = camv->layers.used;
+			res = camv->layers.used;
+			vtp0_append(&camv->layers, layer);
+		}
+		else {
+			vtp0_insert_len(&camv->layers, camv->grp_idx_last, &layer, 1);
+			res = camv->grp_idx_last;
+		}
+	}
+	else {
+		res = camv->layers.used;
+		vtp0_append(&camv->layers, layer);
+	}
+	layer->parent = camv;
+	return res;
+}
+
+long camv_sublayer_append_after(camv_design_t *camv, camv_layer_t *layer, long idx)
+{
+	idx++;
+	vtp0_insert_len(&camv->layers, idx, &layer, 1);
+	return idx;
+}
 
 camv_layer_t *camv_layer_by_name(camv_design_t *camv, const char *name, int alloc)
 {
@@ -191,7 +229,8 @@ void camv_data_bbox(camv_design_t *camv)
 {
 	long lid;
 
-	camv->bbox.x1 = camv->bbox.x2 = camv->bbox.y1 = camv->bbox.y2 = 0;
+	camv->bbox.x1 = camv->bbox.y1 = RND_COORD_MAX;
+	camv->bbox.x2 = camv->bbox.y2 = -RND_COORD_MAX;
 	for(lid = 0; lid < camv->layers.used; lid++) {
 		camv_layer_t *ly = (camv_layer_t *)camv->layers.array[lid];
 		if (ly->objs.size != 0) {
@@ -199,4 +238,16 @@ void camv_data_bbox(camv_design_t *camv)
 			rnd_box_bump_point((rnd_box_t *)&camv->bbox, ly->objs.bbox.x2, ly->objs.bbox.y2);
 		}
 	}
+
+	if ((camv->bbox.x1 == RND_COORD_MAX) || (camv->bbox.y1 == RND_COORD_MAX) || (camv->bbox.x2 == -RND_COORD_MAX) || (camv->bbox.y2 == -RND_COORD_MAX)) {
+		/* empty layer - make it 1*1 mm so it's easier to handle */
+		camv->bbox.x1 = camv->bbox.y1 = 0;
+		camv->bbox.x2 = camv->bbox.y2 = RND_MM_TO_COORD(1);
+	}
+}
+
+void camv_layer_select(camv_design_t *camv, int idx)
+{
+	camv->lysel = idx;
+	rnd_event(&camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", idx);
 }
