@@ -1,6 +1,11 @@
+#ifndef CAMV_DRAW_H
+#define CAMV_DRAW_H
+
 typedef struct rnd_xform_s {
 	int dummy;
 } rnd_xform_t;
 
 void camv_expose_main(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *region, rnd_xform_t *xform_caller);
-void camv_expose_preview(rnd_hid_t *hid, const rnd_hid_expose_ctx_t *e);
+void camv_expose_preview(rnd_hid_t *hid, rnd_hid_expose_ctx_t *e);
+
+#endif
