@@ -30,7 +30,7 @@
 #include "config.h"
 #include <librnd/core/actions.h>
 #include "conf_core.h"
-#include <librnd/core/hid_init.h>
+#include <librnd/hid/hid_init.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/safe_fs.h>
 #include "data.h"
@@ -228,12 +228,12 @@ fgw_error_t camv_act_System(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_CONVARG(1, FGW_STR, System, cmd = argv[1].val.str);
 	RND_ACT_IRES(0);
 
-/*	rnd_setenv("CAMV_RND_LAYER_FILE_NAME", RND_ACT_HIDLIB->filename == NULL ? "" : RND_ACT_HIDLIB->filename, 1);*/
+/*	rnd_setenv("CAMV_RND_LAYER_FILE_NAME", RND_ACT_DESIGN->loadname == NULL ? "" : RND_ACT_DESIGN->loadname, 1);*/
 	rnd_snprintf(tmp, sizeof(tmp), "%mm", camv.crosshair_x);
 	rnd_setenv("CAMV_RND_CROSSHAIR_X_MM", tmp, 1);
 	rnd_snprintf(tmp, sizeof(tmp), "%mm", camv.crosshair_y);
 	rnd_setenv("CAMV_RND_CROSSHAIR_Y_MM", tmp, 1);
-	RND_ACT_IRES(rnd_system(RND_ACT_HIDLIB, cmd));
+	RND_ACT_IRES(rnd_system(RND_ACT_DESIGN, cmd));
 	return 0;
 }
 
@@ -246,7 +246,7 @@ fgw_error_t camv_act_ExecuteFile(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	const char *fname;
 
 	RND_ACT_CONVARG(1, FGW_STR, ExecuteFile, fname = argv[1].val.str);
-	RND_ACT_IRES(rnd_act_execute_file(RND_ACT_HIDLIB, fname));
+	RND_ACT_IRES(rnd_act_execute_file(RND_ACT_DESIGN, fname));
 	return 0;
 }
 
