@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  camv-rnd - electronics-related CAM viewer
- *  Copyright (C) 2019,2020 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2019,2020,2023 Tibor 'Igor2' Palinkas
  *  (copied from pcb-rnd by the author)
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -43,6 +43,11 @@
 
 #include "layersel.h"
 
+/* Enable this to make sublayers and layer indices visible */
+#if 0
+#define LAYERSEL_DEBUG
+#endif
+
 static const char *xpm_up[] = {
 "10 10 3 1",
 " 	c None",
@@ -201,7 +206,6 @@ struct layersel_ctx_s {
 	int sub_inited;
 	int wbut_up, wbut_down, wbut_top, wbut_bottom, wbut_load, wbut_remove, wbut_vis, wbut_invis;
 	int lock_vis, lock_sel;
-	int selected; /* layer idx (lid) of the currently selected layer */
 	vtp0_t layers; /* -> ls_layer_t */
 };
 
@@ -245,14 +249,14 @@ static void layer_vis_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *
 static void layer_unselect(layersel_ctx_t *ls)
 {
 	ls_layer_t **lys;
-	if (ls->selected < 0)
+	if (ls->camv->lysel < 0)
 		return;
 
-	lys = (ls_layer_t **)vtp0_get(&ls->layers, ls->selected, 0);
+	lys = (ls_layer_t **)vtp0_get(&ls->layers, ls->camv->lysel, 0);
 	if (lys != NULL)
 		rnd_gui->attr_dlg_widget_state(ls->sub.dlg_hid_ctx, (*lys)->wlab, 1);
-	ls->selected = -1;
-	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", ls->selected);
+
+	camv_layer_select(ls->camv, -1);
 }
 
 static void layer_select_idx(layersel_ctx_t *ls, int idx)
@@ -260,13 +264,11 @@ static void layer_select_idx(layersel_ctx_t *ls, int idx)
 	ls_layer_t **lys;
 	layer_unselect(ls);
 	lys = (ls_layer_t **)vtp0_get(&ls->layers, idx, 0);
-	if (lys != NULL) {
+	if (lys != NULL)
 		rnd_gui->attr_dlg_widget_state(ls->sub.dlg_hid_ctx, (*lys)->wlab, 2);
-		ls->selected = idx;
-	}
 	else
-		ls->selected = -1;
-	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", ls->selected);
+		idx = -1;
+	camv_layer_select(layersel.camv, idx);
 }
 
 static void layer_select(ls_layer_t *lys)
@@ -336,8 +338,11 @@ static void layer_vis_box(gen_xpm_t *dst, int filled, const rnd_color_t *color,
 		dst->xpm[n] = dst->buf[n];
 }
 
-static void layersel_create_layer(layersel_ctx_t *ls, ls_layer_t *lys, const char *short_name, const char *name, const rnd_color_t *color, int brd, int hatch)
+static void layersel_create_layer(layersel_ctx_t *ls, ls_layer_t *lys, int lidx, const char *short_name, const char *name, const rnd_color_t *color, int brd, int hatch)
 {
+	if (name == NULL)
+		name = "<sub>";
+
 	if (short_name == NULL) {
 		short_name = strrchr(name, '/');
 		if (short_name == NULL)
@@ -358,6 +363,13 @@ static void layersel_create_layer(layersel_ctx_t *ls, ls_layer_t *lys, const cha
 			lys->wvis_off = RND_DAD_CURRENT(ls->sub.dlg);
 			RND_DAD_SET_ATTR_FIELD(ls->sub.dlg, user_data, lys);
 			RND_DAD_CHANGE_CB(ls->sub.dlg, layer_vis_cb);
+#ifdef LAYERSEL_DEBUG
+		{
+			char idx[32];
+			sprintf(idx, "{%d}", lidx);
+			RND_DAD_LABEL(ls->sub.dlg, idx);
+		}
+#endif
 		RND_DAD_LABEL(ls->sub.dlg, short_name);
 			lys->wlab = RND_DAD_CURRENT(ls->sub.dlg);
 			RND_DAD_SET_ATTR_FIELD(ls->sub.dlg, user_data, lys);
@@ -379,14 +391,16 @@ static void layersel_docked_create(layersel_ctx_t *ls, camv_design_t *camv)
 			camv_layer_t *ly = camv->layers.array[n];
 			ls_layer_t *lys, **lysp;
 
+#ifndef LAYERSEL_DEBUG
 			if (ly->sub) continue;
+#endif
 			lysp = (ls_layer_t **)vtp0_get(&ls->layers, n, 1);
 			if (*lysp == NULL)
 				*lysp = calloc(sizeof(ls_layer_t), 1);
 			lys = *lysp;
 			lys->lid = n;
 			lys->ls = ls;
-			layersel_create_layer(ls, lys, ly->short_name, ly->name, &ly->color, 1, 0);
+			layersel_create_layer(ls, lys, n, ly->short_name, ly->name, &ly->color, 1, 0);
 			i++;
 		}
 
@@ -487,7 +501,7 @@ void camv_layersel_layer_chg_ev(rnd_design_t *hidlib, void *user_data, int argc,
 
 static void layer_move(int dst)
 {
-	int step, n, src = layersel.selected;
+	int step, n, src = layersel.camv->lysel;
 	camv_design_t *camv = layersel.camv;
 	camv_layer_t *dst_ly = camv->layers.array[src];
 
@@ -503,22 +517,21 @@ static void layer_move(int dst)
 
 static void layer_del(void)
 {
-	int src = layersel.selected;
+	int src = layersel.camv->lysel;
 	camv_layer_t *ly = layersel.camv->layers.array[src];
 
 	vtp0_remove(&layersel.camv->layers, src, 1);
 	vtp0_remove(&layersel.layers, src, 1);
 	camv_layer_destroy(ly);
 
-	layersel.selected = -1;
+	camv_layer_select(layersel.camv, -1);
 	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
-	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", layersel.selected);
 	camv_hid_redraw(layersel.camv);
 }
 
 static void layer_set_color(const rnd_color_t clr)
 {
-	int src = layersel.selected;
+	int src = layersel.camv->lysel;
 	camv_layer_t *ly = layersel.camv->layers.array[src];
 
 	ly->color = clr;
@@ -527,7 +540,7 @@ static void layer_set_color(const rnd_color_t clr)
 
 static void layer_rename(const char *name)
 {
-	int src = layersel.selected;
+	int src = layersel.camv->lysel;
 	camv_layer_t *ly = layersel.camv->layers.array[src];
 
 	free(ly->short_name);
@@ -546,9 +559,9 @@ static void layer_del_all(void)
 		camv_layer_destroy(ly);
 	}
 
-	layersel.selected = -1;
+	camv_layer_select(layersel.camv, -1);
 	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYERS_CHANGED, NULL);
-	rnd_event(&layersel.camv->hidlib, CAMV_EVENT_LAYER_SELECTED, "i", layersel.selected);
+
 	camv_hid_redraw(layersel.camv);
 }
 
@@ -577,27 +590,27 @@ fgw_error_t camv_act_Layer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	RND_ACT_CONVARG(1, FGW_STR, Layer, cmd = argv[1].val.str);
 
 	if (strcmp(cmd, "down") == 0) {
-		if (layersel.selected < 0) goto nolayer;
-		if (layersel.selected == 0) goto nop;
-		layer_move(layersel.selected-1);
+		if (camv->lysel < 0) goto nolayer;
+		if (camv->lysel == 0) goto nop;
+		layer_move(camv->lysel-1);
 	}
 	else if (strcmp(cmd, "up") == 0) {
-		if (layersel.selected < 0) goto nolayer;
-		if (layersel.selected == camv->layers.used-1) goto nop;
-		layer_move(layersel.selected+1);
+		if (camv->lysel < 0) goto nolayer;
+		if (camv->lysel == camv->layers.used-1) goto nop;
+		layer_move(camv->lysel+1);
 	}
 	else if (strcmp(cmd, "bottom") == 0) {
-		if (layersel.selected < 0) goto nolayer;
-		if (layersel.selected == 0) goto nop;
+		if (camv->lysel < 0) goto nolayer;
+		if (camv->lysel == 0) goto nop;
 		layer_move(0);
 	}
 	else if (strcmp(cmd, "top") == 0) {
-		if (layersel.selected < 0) goto nolayer;
-		if (layersel.selected == camv->layers.used-1) goto nop;
+		if (camv->lysel < 0) goto nolayer;
+		if (camv->lysel == camv->layers.used-1) goto nop;
 		layer_move(camv->layers.used-1);
 	}
 	else if (strcmp(cmd, "del") == 0) {
-		if (layersel.selected < 0) goto nolayer;
+		if (camv->lysel < 0) goto nolayer;
 		layer_del();
 	}
 	else if (strcmp(cmd, "all-visible") == 0) {
@@ -607,11 +620,11 @@ fgw_error_t camv_act_Layer(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		all_vis(camv, 0);
 	}
 	else if (rnd_strcasecmp(cmd, "delall") == 0) {
-		if (layersel.selected < 0) goto nolayer;
+		if (camv->lysel < 0) goto nolayer;
 		layer_del_all();
 	}
 	else if (rnd_strcasecmp(cmd, "getidx") == 0) {
-		RND_ACT_IRES(layersel.selected);
+		RND_ACT_IRES(camv->lysel);
 		return 0;
 	}
 	else if (rnd_strcasecmp(cmd, "select") == 0) {
